# WeatherFlow Forecast API

Python Library to retrieve Forecast data from WeatherFlow.

Please visit <https://weatherflow.github.io/Tempest/api/swagger/> for more information.

TODO:
- Expand documentation, to show usage. In the meatime, for a non Async usage see `test_module.py`
- Improve documentation

If you want to contribute you can use devcontainers in vscode for easiest setup. Please see [instructions here](.devcontainer/README.md)
